==> qtjambi-quick-debuginfo-macos-5.15.18.jar: sources/QtJambiQuick/QSGTransformNode_shell.cpp <==
#include "QSGTransformNode_shell.h"

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtJambi/Cast>

void deleter_QSGTransformNode(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QSGTransformNode")
    QSGTransformNode *_ptr = reinterpret_cast<QSGTransformNode *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QSGTransformNode_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QSGTransformNode_shell) ); }

jmethodID QSGTransformNode_shell::__shell_javaMethod(int pos) const { return QSGTransformNode_shell::__shell()->javaMethod(typeid(QSGTransformNode), pos); }

// emitting (writeShellConstructor)
QSGTransformNode_shell::QSGTransformNode_shell()
    : QSGTransformNode()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QSGTransformNode::QSGTransformNode_shell()", QSGTransformNode_shell::__shell())
    QSGTransformNode_shell::__shell()->constructed(typeid(QSGTransformNode));
}

// emitting (writeShellDestructor)
QSGTransformNode_shell::~QSGTransformNode_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QSGTransformNode::~QSGTransformNode()", QSGTransformNode_shell::__shell())
    QSGTransformNode_shell::__shell()->destructed(typeid(QSGTransformNode));
}

void QSGTransformNode_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QSGTransformNode_shell*>(ptr)->QSGTransformNode_shell::__shell()->tryDeleteShell(typeid(QSGTransformNode));
}

// emitting Virtual overrides (virtualFunctions)
bool QSGTransformNode_shell::isSubtreeBlocked() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QSGTransformNode::", QSGTransformNode_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            bool  __qt_return_value = false;
            QTJAMBI_TRY {
                if(jobject __java_this = QSGTransformNode_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jboolean __java_return_value = __jni_env->CallBooleanMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = static_cast<bool>(__java_return_value);
                } else {
                    QSGTransformNode_shell::__shell()->warnForMethod("QSGTransformNode::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QSGTransformNode::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QSGNode::isSubtreeBlocked();
        }
    }else{
        return QSGNode::isSubtreeBlocked();
    }
}

void QSGTransformNode_shell::preprocess()
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QSGTransformNode::", QSGTransformNode_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QSGTransformNode_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QSGTransformNode_shell::__shell()->warnForMethod("QSGTransformNode::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QSGTransformNode::");
            } QTJAMBI_TRY_END
        }else{
            QSGNode::preprocess();
        }
    }else{
        QSGNode::preprocess();
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QSGTransformNode()
void __qt_construct_QSGTransformNode_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QSGTransformNode()")
    Q_UNUSED(__java_arguments)
    QSGTransformNode *__qt_this = new(__qtjambi_ptr) QSGTransformNode_shell();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QSGTransformNode_shell
void __qt_destruct_QSGTransformNode(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QSGTransformNode")
    reinterpret_cast<QSGTransformNode_shell*>(ptr)->~QSGTransformNode_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QSGTransformNode::QSGTransformNode()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGTransformNode_initialize_1native__Lio_qt_quick_QSGTransformNode_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QSGTransformNode::QSGTransformNode()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QSGTransformNode_0, sizeof(QSGTransformNode_shell), typeid(QSGTransformNode), true, &deleter_QSGTransformNode, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QSGTransformNode::combinedMatrix()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGTransformNode_combinedMatrix_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QSGTransformNode *__qt_this = QtJambiAPI::objectFromNativeId<QSGTransformNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGTransformNode::combinedMatrix()const", __qt_this)
        const QMatrix4x4& __qt_return_value = __qt_this->combinedMatrix();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QSGTransformNode::matrix()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGTransformNode_matrix_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QSGTransformNode *__qt_this = QtJambiAPI::objectFromNativeId<QSGTransformNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGTransformNode::matrix()const", __qt_this)
        const QMatrix4x4& __qt_return_value = __qt_this->matrix();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QSGTransformNode::setCombinedMatrix(QMatrix4x4)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGTransformNode_setCombinedMatrix_1native_1cref_1QMatrix4x4__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID matrix0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QSGTransformNode *__qt_this = QtJambiAPI::objectFromNativeId<QSGTransformNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGTransformNode::setCombinedMatrix(QMatrix4x4)", __qt_this)
        const QMatrix4x4& __qt_matrix0 = QtJambiAPI::valueReferenceFromNativeId<QMatrix4x4>(matrix0);
        __qt_this->setCombinedMatrix(__qt_matrix0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QSGTransformNode::setMatrix(QMatrix4x4)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGTransformNode_setMatrix_1native_1cref_1QMatrix4x4__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID matrix0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QSGTransformNode *__qt_this = QtJambiAPI::objectFromNativeId<QSGTransformNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGTransformNode::setMatrix(QMatrix4x4)", __qt_this)
        const QMatrix4x4& __qt_matrix0 = QtJambiAPI::valueReferenceFromNativeId<QMatrix4x4>(matrix0);
        __qt_this->setMatrix(__qt_matrix0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

#include <QtCore/QDebug>
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGTransformNode_toString_1native)(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jstring __java_return_value = nullptr;
    QTJAMBI_TRY {
        QSGTransformNode *__qt_this = QtJambiAPI::objectFromNativeId<QSGTransformNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QString res;
        QDebug(&res).noquote() << __qt_this;
        if(!res.isEmpty() && res.back().isSpace())
            res = res.trimmed();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, res);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QSGTransformNode(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QSGTransformNode>("QSGTransformNode", "io/qt/quick/QSGTransformNode");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "isSubtreeBlocked", "()Z"),
        FunctionInfo(/* 1 */ "preprocess", "()V")});
    registerConstructorInfos(typeId, &__qt_destruct_QSGTransformNode, {
        ConstructorInfo(&__qt_construct_QSGTransformNode_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QSGTransformNode);
    registerSizeOfShell(typeId, sizeof(QSGTransformNode_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QSGNode, QSGTransformNode>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-quick-debuginfo-macos-6.5.7.jar: sources/QtJambiQuick/QSGTransformNode_shell.cpp <==
#include "QSGTransformNode_shell.h"

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtJambi/Cast>

void deleter_QSGTransformNode(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QSGTransformNode")
    QSGTransformNode *_ptr = reinterpret_cast<QSGTransformNode *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QSGTransformNode_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QSGTransformNode_shell) ); }

jmethodID QSGTransformNode_oshell::__shell_javaMethod(int pos) const { return QSGTransformNode_shell::__shell()->javaMethod(typeid(QSGTransformNode), pos); }

// emitting (writeShellDestructor)
QSGTransformNode_shell::~QSGTransformNode_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QSGTransformNode::~QSGTransformNode()", this)
    QSGTransformNode_shell::__shell()->destructed(typeid(QSGTransformNode));
}

// emitting (writeShellConstructor)
QSGTransformNode_shell::QSGTransformNode_shell()
    : QSGTransformNode()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QSGTransformNode::QSGTransformNode_shell()", this)
    QSGTransformNode_shell::__shell()->constructed(typeid(QSGTransformNode));
}

void QSGTransformNode_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QSGTransformNode_shell*>(ptr)->QSGTransformNode_shell::__shell()->tryDeleteShell(typeid(QSGTransformNode));
}

void QSGTransformNode_oshell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QSGTransformNode_oshell*>(ptr)->QSGTransformNode_oshell::__shell()->tryDeleteShell(typeid(QSGTransformNode));
}

// emitting Virtual overrides (virtualFunctions)
bool QSGTransformNode_oshell::isSubtreeBlocked() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QSGTransformNode::isSubtreeBlocked()const", this)
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            bool  __qt_return_value = false;
            QTJAMBI_TRY {
                if(jobject __java_this = QSGTransformNode_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jboolean __java_return_value = __jni_env->CallBooleanMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = static_cast<bool>(__java_return_value);
                } else {
                    QSGTransformNode_shell::__shell()->warnForMethod("QSGTransformNode::isSubtreeBlocked()const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QSGTransformNode::isSubtreeBlocked()const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QSGNode::isSubtreeBlocked();
        }
    }else{
        return QSGNode::isSubtreeBlocked();
    }
}

void QSGTransformNode_oshell::preprocess()
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QSGTransformNode::preprocess()", this)
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QSGTransformNode_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QSGTransformNode_shell::__shell()->warnForMethod("QSGTransformNode::preprocess()");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QSGTransformNode::preprocess()");
            } QTJAMBI_TRY_END
        }else{
            QSGNode::preprocess();
        }
    }else{
        QSGNode::preprocess();
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QSGTransformNode()
void __qt_construct_QSGTransformNode(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool __qtjambi_has_overrides, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QSGTransformNode()")
    Q_UNUSED(__java_arguments)
    QSGTransformNode *__qt_this;
    if(__qtjambi_has_overrides)
        __qt_this = new(__qtjambi_ptr) QSGTransformNode_oshell();
    else
        __qt_this = new(__qtjambi_ptr) QSGTransformNode_shell();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QSGTransformNode::QSGTransformNode()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGTransformNode_initialize_1native__Lio_qt_quick_QSGTransformNode_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QSGTransformNode::QSGTransformNode()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QSGTransformNode, sizeof(QSGTransformNode_shell), typeid(QSGTransformNode), 0, true, &deleter_QSGTransformNode, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QSGTransformNode_shell
void __qt_destruct_QSGTransformNode(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QSGTransformNode")
    reinterpret_cast<QSGTransformNode_shell*>(ptr)->~QSGTransformNode_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QSGTransformNode::combinedMatrix()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGTransformNode_combinedMatrix_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QSGTransformNode *__qt_this = QtJambiAPI::objectFromNativeId<QSGTransformNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGTransformNode::combinedMatrix()const", __this_nativeId)
        const QMatrix4x4& __qt_return_value = __qt_this->combinedMatrix();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QSGTransformNode::matrix()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGTransformNode_matrix_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QSGTransformNode *__qt_this = QtJambiAPI::objectFromNativeId<QSGTransformNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGTransformNode::matrix()const", __this_nativeId)
        const QMatrix4x4& __qt_return_value = __qt_this->matrix();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QSGTransformNode::setCombinedMatrix(QMatrix4x4)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGTransformNode_setCombinedMatrix_1native_1cref_1QMatrix4x4__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID matrix0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QSGTransformNode *__qt_this = QtJambiAPI::objectFromNativeId<QSGTransformNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGTransformNode::setCombinedMatrix(QMatrix4x4)", __this_nativeId)
        const QMatrix4x4& __qt_matrix0 = QtJambiAPI::valueReferenceFromNativeId<QMatrix4x4>(matrix0);
        __qt_this->setCombinedMatrix(__qt_matrix0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QSGTransformNode::setMatrix(QMatrix4x4)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGTransformNode_setMatrix_1native_1cref_1QMatrix4x4__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID matrix0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QSGTransformNode *__qt_this = QtJambiAPI::objectFromNativeId<QSGTransformNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGTransformNode::setMatrix(QMatrix4x4)", __this_nativeId)
        const QMatrix4x4& __qt_matrix0 = QtJambiAPI::valueReferenceFromNativeId<QMatrix4x4>(matrix0);
        __qt_this->setMatrix(__qt_matrix0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

#include <QtCore/QDebug>
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGTransformNode_toString_1native)(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jstring __java_return_value = nullptr;
    QTJAMBI_TRY {
        QSGTransformNode *__qt_this = QtJambiAPI::objectFromNativeId<QSGTransformNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QString res;
        QDebug(&res).noquote() << __qt_this;
        if(!res.isEmpty() && res.back().isSpace())
            res = res.trimmed();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, res);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QSGTransformNode(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QSGTransformNode>("QSGTransformNode", "io/qt/quick/QSGTransformNode");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "isSubtreeBlocked", "()Z"),
        FunctionInfo(/* 1 */ "preprocess", "()V")});
    registerConstructorInfos(typeId, 0, &__qt_destruct_QSGTransformNode, {
        ConstructorInfo(&__qt_construct_QSGTransformNode, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QSGTransformNode);
    registerSizeOfShell(typeId, sizeof(QSGTransformNode_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QSGNode, QSGTransformNode>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
